@@ -23,8 +23,7 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
+#include <gio/gio.h>
 #include <string.h>
 
 #include "eel-gconf-extensions.h"
@@ -47,6 +46,7 @@
 #define MAX_TITLE_LENGTH        512 /* characters */
 #define RELOAD_DELAY            250 /* ms */
 #define RELOAD_DELAY_MAX_TICKS  40  /* RELOAD_DELAY * RELOAD_DELAY_MAX_TICKS = 10 s */
+#define EMPTY_PAGE              _("Blank page") /* Title for the empty page */
 
 struct _EphyBaseEmbedPrivate {
   EphyEmbedAddressExpire address_expire;
@@ -55,12 +55,10 @@ struct _EphyBaseEmbedPrivate {
   /* guint security_level : 3; ? */
   EphyEmbedDocumentType document_type;
   EphyEmbedNavigationFlags nav_flags;
-  float zoom;
 
   /* Flags */
   guint is_blank : 1;
   guint is_loading : 1;
-  guint is_setting_zoom : 1;
   guint visibility : 1;
 
   gint8 load_percent;
@@ -76,7 +74,8 @@ struct _EphyBaseEmbedPrivate {
   GdkPixbuf *icon;
 
   /* File watch */
-  GnomeVFSMonitorHandle *monitor;
+  GFileMonitor *monitor;
+  gboolean monitor_directory;
   guint reload_scheduled_id;
   guint reload_delay_ticks;
 
@@ -107,7 +106,6 @@ enum {
   PROP_TITLE,
   PROP_VISIBLE,
   PROP_TYPED_ADDRESS,
-  PROP_ZOOM
 };
 
 #define EPHY_BASE_EMBED_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BASE_EMBED, EphyBaseEmbedPrivate))
@@ -479,7 +477,6 @@ ephy_base_embed_set_property (GObject *object,
     case PROP_SECURITY:
     case PROP_STATUS_MESSAGE:
     case PROP_VISIBLE:
-    case PROP_ZOOM:
       /* read only */
       break;
     default:
@@ -583,9 +580,6 @@ ephy_base_embed_get_property (GObject *object,
     case PROP_VISIBLE:
       g_value_set_boolean (value, priv->visibility);
       break;
-    case PROP_ZOOM:
-      g_value_set_float (value, priv->zoom);
-      break;
     default:
       break;
   }
@@ -622,15 +616,7 @@ ephy_base_embed_class_init (EphyBaseEmbedClass *klass)
                                                       EPHY_TYPE_EMBED_DOCUMENT_TYPE,
                                                       EPHY_EMBED_DOCUMENT_HTML,
                                                       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-  g_object_class_install_property (gobject_class,
-                                   PROP_ZOOM,
-                                   g_param_spec_float ("zoom",
-                                                       "Zoom",
-                                                       "The embed's zoom",
-                                                       ZOOM_MINIMAL,
-                                                       ZOOM_MAXIMAL,
-                                                       1.0,
-                                                       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+
   g_object_class_install_property (gobject_class,
                                    PROP_LOAD_PROGRESS,
                                    g_param_spec_int ("load-progress",
@@ -674,7 +660,7 @@ ephy_base_embed_class_init (EphyBaseEmbedClass *klass)
                                    g_param_spec_string ("title",
                                                         "Title",
                                                         "The embed's title",
-                                                        _ ("Blank page"),
+                                                        EMPTY_PAGE,
                                                         G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
   g_object_class_install_property (gobject_class,
                                    PROP_STATUS_MESSAGE,
@@ -764,41 +750,6 @@ ge_document_type_cb (EphyEmbed *embed,
   }
 }
 
-static void
-ge_zoom_change_cb (EphyEmbed *embed,
-                   float zoom,
-                   EphyBaseEmbed *bembed)
-{
-  char *address;
-
-  if (bembed->priv->zoom != zoom) {
-    if (bembed->priv->is_setting_zoom) {
-      return;
-    }
-
-    address = ephy_embed_get_location (embed, TRUE);
-    if (ephy_embed_utils_address_has_web_scheme (address)) {
-      EphyHistory *history;
-      EphyNode *host;
-      history = EPHY_HISTORY
-                (ephy_embed_shell_get_global_history (embed_shell));
-      host = ephy_history_get_host (history, address);
-
-      if (host != NULL) {
-        ephy_node_set_property_float (host,
-                                      EPHY_NODE_HOST_PROP_ZOOM,
-                                      zoom);
-      }
-    }
-
-    g_free (address);
-
-    bembed->priv->zoom = zoom;
-
-    g_object_notify (G_OBJECT (embed), "zoom");
-  }
-}
-
 static void
 ge_favicon_cb (EphyEmbed *membed,
                const char *address,
@@ -893,10 +844,6 @@ ephy_base_embed_init (EphyBaseEmbed *self)
                            G_CALLBACK (ge_document_type_cb),
                            self, (GConnectFlags)0);
 
-  g_signal_connect_object (self, "ge_zoom_change",
-                           G_CALLBACK (ge_zoom_change_cb),
-                           self, (GConnectFlags)0);
-
   g_signal_connect_object (self, "ge_favicon",
                            G_CALLBACK (ge_favicon_cb),
                            self, (GConnectFlags)0);
@@ -917,10 +864,10 @@ ephy_base_embed_init (EphyBaseEmbed *self)
 
   priv->document_type = EPHY_EMBED_DOCUMENT_HTML;
   priv->security_level = EPHY_EMBED_STATE_IS_UNKNOWN;
-  priv->zoom = 1.0;
   priv->address_expire = EPHY_EMBED_ADDRESS_EXPIRE_NOW;
   priv->is_blank = TRUE;
-  priv->title = g_strdup (_("Blank page"));
+  priv->title = g_strdup (EMPTY_PAGE);
+  priv->monitor_directory = FALSE;
 }
 
 static void
@@ -999,27 +946,13 @@ ephy_base_embed_set_address (EphyBaseEmbed *embed,
   g_object_notify (object, "address");
 }
 
-static char *
+static char*
 get_title_from_address (const char *address)
 {
-  GnomeVFSURI *uri;
-  char *title;
-
-  if (address == NULL) return NULL;
-
-  uri = gnome_vfs_uri_new (address);
-  if (uri == NULL) return g_strdup (address);
-
-  title = gnome_vfs_uri_to_string (uri,
-                                   (GnomeVFSURIHideOptions)
-                                   (GNOME_VFS_URI_HIDE_USER_NAME |
-                                    GNOME_VFS_URI_HIDE_PASSWORD |
-                                    GNOME_VFS_URI_HIDE_HOST_PORT |
-                                    GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD |
-                                    GNOME_VFS_URI_HIDE_FRAGMENT_IDENTIFIER));
-  gnome_vfs_uri_unref (uri);
-
-  return title;
+  if (g_str_has_prefix (address, "file://")) 
+    return g_strdup (address + 7);
+  else
+    return ephy_string_get_host_name (address);
 }
 
 void
@@ -1036,12 +969,12 @@ ephy_base_embed_set_title (EphyBaseEmbed *embed,
     /* Fallback */
     if (title == NULL || title[0] == '\0') {
       g_free (title);
-      title = NULL;
+      title = g_strdup (EMPTY_PAGE);
       priv->is_blank = TRUE;
     }
-  } else if (priv->is_blank && title != NULL) {
+  } else if (priv->is_blank) {
     g_free (title);
-    title = NULL;
+    title = g_strdup (EMPTY_PAGE);
   }
 
   g_free (priv->title);
@@ -1068,19 +1001,13 @@ ensure_page_info (EphyBaseEmbed *embed, const char *address)
 static void
 update_net_state_message (EphyBaseEmbed *embed, const char *uri, EphyEmbedNetState flags)
 {
-  GnomeVFSURI *vfs_uri = NULL;
   const char *msg = NULL;
-  const char *host = NULL;
+  char *host = NULL;
 
-  if (uri != NULL) {
-    vfs_uri = gnome_vfs_uri_new (uri);
-  }
+  if (uri != NULL)
+    host = ephy_string_get_host_name (uri);
 
-  if (vfs_uri != NULL) {
-    host = gnome_vfs_uri_get_host_name (vfs_uri);
-  }
-
-  if (host == NULL || host[0] == '\0') goto out;
+  if (host == NULL) goto out;
 
   /* IS_REQUEST and IS_NETWORK can be both set */
   if (flags & EPHY_EMBED_STATE_IS_REQUEST) {
@@ -1115,9 +1042,7 @@ update_net_state_message (EphyBaseEmbed *embed, const char *uri, EphyEmbedNetSta
   }
 
  out:
-  if (vfs_uri != NULL) {
-    gnome_vfs_uri_unref (vfs_uri);
-  }
+    g_free (host);
 }
 
 static void
@@ -1126,16 +1051,17 @@ update_navigation_flags (EphyBaseEmbed *membed)
   EphyBaseEmbedPrivate *priv = membed->priv;
   EphyEmbed *embed = EPHY_EMBED (membed);
   guint flags = 0;
+  WebKitWebView *web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
 
   if (ephy_embed_can_go_up (embed)) {
     flags |= EPHY_EMBED_NAV_UP;
   }
 
-  if (ephy_embed_can_go_back (embed)) {
+  if (webkit_web_view_can_go_back (web_view)) {
     flags |= EPHY_EMBED_NAV_BACK;
   }
 
-  if (ephy_embed_can_go_forward (embed)) {
+  if (webkit_web_view_can_go_forward (web_view)) {
     flags |= EPHY_EMBED_NAV_FORWARD;
   }
 
@@ -1287,8 +1213,8 @@ ephy_base_embed_file_monitor_cancel (EphyBaseEmbed *embed)
 
   if (priv->monitor != NULL) {
     LOG ("Cancelling file monitor");
-
-    gnome_vfs_monitor_cancel (priv->monitor);
+    
+    g_file_monitor_cancel (G_FILE_MONITOR (priv->monitor));
     priv->monitor = NULL;
   }
 
@@ -1325,47 +1251,39 @@ ephy_base_embed_file_monitor_reload_cb (EphyBaseEmbed *embed)
   priv->reload_scheduled_id = 0;
 
   LOG ("Reloading file '%s'", ephy_embed_get_address (EPHY_EMBED (embed)));
-
-  ephy_embed_reload (EPHY_EMBED (embed), TRUE);
+  webkit_web_view_reload (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
 
   /* don't run again */
   return FALSE;
 }
 
 static void
-ephy_base_embed_file_monitor_cb (GnomeVFSMonitorHandle *handle,
-                                 const gchar *monitor_uri,
-                                 const gchar *info_uri,
-                                 GnomeVFSMonitorEventType event_type,
+ephy_base_embed_file_monitor_cb (GFileMonitor *monitor,
+                                 GFile *file,
+                                 GFile *other_file,
+                                 GFileMonitorEvent event_type,
                                  EphyBaseEmbed *embed)
 {
-  gboolean uri_is_directory;
   gboolean should_reload;
-  char *local_path;
   EphyBaseEmbedPrivate *priv = embed->priv;
 
-  LOG ("File '%s' has changed, scheduling reload", monitor_uri);
-
-  local_path = gnome_vfs_get_local_path_from_uri (monitor_uri);
-  uri_is_directory = g_file_test (local_path, G_FILE_TEST_IS_DIR);
-  g_free (local_path);
-
   switch (event_type) {
     /* These events will always trigger a reload: */
-    case GNOME_VFS_MONITOR_EVENT_CHANGED:
-    case GNOME_VFS_MONITOR_EVENT_CREATED:
+    case G_FILE_MONITOR_EVENT_CHANGED:
+    case G_FILE_MONITOR_EVENT_CREATED:
       should_reload = TRUE;
       break;
 
-      /* These events will only trigger a reload for directories: */
-    case GNOME_VFS_MONITOR_EVENT_DELETED:
-    case GNOME_VFS_MONITOR_EVENT_METADATA_CHANGED:
-      should_reload = uri_is_directory;
+    /* These events will only trigger a reload for directories: */
+    case G_FILE_MONITOR_EVENT_DELETED:
+    case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED:
+      should_reload = priv->monitor_directory;
       break;
 
-      /* These events don't trigger a reload: */
-    case GNOME_VFS_MONITOR_EVENT_STARTEXECUTING:
-    case GNOME_VFS_MONITOR_EVENT_STOPEXECUTING:
+    /* These events don't trigger a reload: */
+    case G_FILE_MONITOR_EVENT_PRE_UNMOUNT:
+    case G_FILE_MONITOR_EVENT_UNMOUNTED:
+    case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
     default:
       should_reload = FALSE;
       break;
@@ -1398,10 +1316,13 @@ ephy_base_embed_update_file_monitor (EphyBaseEmbed *embed,
                                      const gchar *address)
 {
   EphyBaseEmbedPrivate *priv = embed->priv;
-  GnomeVFSMonitorHandle *handle = NULL;
   gboolean local;
-  char *local_path;
-  GnomeVFSMonitorType monitor_type;
+  gchar *anchor;
+  gchar *url;
+  GFile *file;
+  GFileType file_type;
+  GFileInfo *file_info;
+  GFileMonitor *monitor = NULL;
 
   if (priv->monitor != NULL &&
       priv->address != NULL && address != NULL &&
@@ -1415,25 +1336,51 @@ ephy_base_embed_update_file_monitor (EphyBaseEmbed *embed,
   local = g_str_has_prefix (address, "file://");
   if (local == FALSE) return;
 
-  local_path = gnome_vfs_get_local_path_from_uri (address);
-  monitor_type = g_file_test (local_path, G_FILE_TEST_IS_DIR)
-                 ? GNOME_VFS_MONITOR_DIRECTORY
-                 : GNOME_VFS_MONITOR_FILE;
-  g_free (local_path);
-
-  if (gnome_vfs_monitor_add (&handle, address,
-                             monitor_type,
-                             (GnomeVFSMonitorCallback)ephy_base_embed_file_monitor_cb,
-                             embed) == GNOME_VFS_OK) {
-    LOG ("Installed monitor for file '%s'", address);
-
-    priv->monitor = handle;
+  /* strip off anchors */
+  anchor = strchr (address, '#');
+  if (anchor != NULL) {
+    url = g_strndup (address, anchor - address);
+  } else {
+    url = g_strdup (address);
   }
+
+  file = g_file_new_for_uri (url);
+  file_info = g_file_query_info (file,
+                                 G_FILE_ATTRIBUTE_STANDARD_TYPE,
+                                 0, NULL, NULL);
+  if (file_info == NULL) {
+    g_object_unref (file);
+    g_free (url);
+    return;
+  }
+
+  file_type = g_file_info_get_file_type (file_info);
+  g_object_unref (file_info);
+
+  if (file_type == G_FILE_TYPE_DIRECTORY) {
+    monitor = g_file_monitor_directory (file, 0, NULL, NULL);
+    g_signal_connect (monitor, "changed",
+                      G_CALLBACK (ephy_base_embed_file_monitor_cb),
+                      embed);
+    priv->monitor_directory = TRUE;
+    LOG ("Installed monitor for directory '%s'", url);
+  }
+  else if (file_type == G_FILE_TYPE_REGULAR) {
+    monitor = g_file_monitor_file (file, 0, NULL, NULL);
+    g_signal_connect (monitor, "changed",
+                      G_CALLBACK (ephy_base_embed_file_monitor_cb),
+                      embed);
+    priv->monitor_directory = FALSE;
+    LOG ("Installed monitor for file '%s'", url);
+  }
+  priv->monitor = monitor;
+  g_object_unref (file);
+  g_free (url);
 }
 
 void
 ephy_base_embed_location_changed (EphyBaseEmbed *embed,
-                                  char *location)
+                                  const char *location)
 {
   GObject *object = G_OBJECT (embed);
 
@@ -1447,7 +1394,7 @@ ephy_base_embed_location_changed (EphyBaseEmbed *embed,
   if (location == NULL || location[0] == '\0' ||
       strcmp (location, "about:blank") == 0) {
     ephy_base_embed_set_address (embed, NULL);
-    ephy_base_embed_set_title (embed, NULL);
+    ephy_base_embed_set_title (embed, EMPTY_PAGE);
   } else {
     char *embed_address;
 
@@ -1540,38 +1487,6 @@ ephy_base_embed_set_security_level (EphyBaseEmbed *embed,
   }
 }
 
-void
-ephy_base_embed_restore_zoom_level (EphyBaseEmbed *membed,
-                                    const char *address)
-{
-  EphyBaseEmbedPrivate *priv = membed->priv;
-
-  /* restore zoom level */
-  if (ephy_embed_utils_address_has_web_scheme (address)) {
-    EphyHistory *history;
-    EphyNode *host;
-    GValue value = { 0, };
-    float zoom = 1.0, current_zoom;
-
-    history = EPHY_HISTORY
-              (ephy_embed_shell_get_global_history (embed_shell));
-    host = ephy_history_get_host (history, address);
-
-    if (host != NULL && ephy_node_get_property
-        (host, EPHY_NODE_HOST_PROP_ZOOM, &value)) {
-      zoom = g_value_get_float (&value);
-      g_value_unset (&value);
-    }
-
-    current_zoom = ephy_embed_get_zoom (EPHY_EMBED (membed));
-    if (zoom != current_zoom) {
-      priv->is_setting_zoom = TRUE;
-      ephy_embed_set_zoom (EPHY_EMBED (membed), zoom);
-      priv->is_setting_zoom = FALSE;
-    }
-  }
-}
-
 void
 ephy_base_embed_set_visibility (EphyBaseEmbed *embed,
                                 gboolean visibility)
