@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed-persist.c 7964 2008-02-17 23:23:36Z xan $
  */
 
 #include "config.h"
@@ -25,7 +24,7 @@
 #include "ephy-embed-type-builtins.h"
 #include "ephy-debug.h"
 
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 enum
 {
