@@ -15,11 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed.c 7208 2007-07-27 20:27:56Z xan $
  */
 
 #include "config.h"
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
 #include "ephy-embed.h"
 
 #include "ephy-embed-type-builtins.h"
@@ -172,47 +173,6 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
-/**
- * EphyEmbed::ge-location:
- * @embed:
- * @address: the new URL @embed is visiting
- *
- * The ::ge_location signal is emitted when @embed begins to load a new web
- * page. For example, if the user clicks on a link or enters an address or if
- * the previous web page had JavaScript or a META REFRESH tag.
- *
- * The ::ge_location signal will be emitted even when @embed is simply
- * refreshing the same web page.
- **/
-		g_signal_new ("ge_location",
-			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedIface, location),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__STRING,
-			      G_TYPE_NONE,
-			      1,
-			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
-/**
- * EphyEmbed::ge-net-state:
- * @embed:
- * @uri: the URI @embed is loading
- * @state: the #EmbedState of @embed
- *
- * The ::ge_net_state signal is emitted when @embed's network negotiation state
- * changes. For example, this will indicate when page loading is complete or
- * cancelled.
- **/
-		g_signal_new ("ge_net_state",
-			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedIface, net_state),
-			      NULL, NULL,
-			      ephy_marshal_VOID__STRING_FLAGS,
-			      G_TYPE_NONE,
-			      2,
-			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-			      EPHY_TYPE_EMBED_NET_STATE);
 /**
  * EphyEmbed::ge-dom-mouse-click:
  * @embed:
@@ -246,65 +206,6 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_BOOLEAN,
 			      1,
 			      G_TYPE_OBJECT);
-/**
- * EphyEmbed::ge-security-change:
- * @embed:
- * @level: @embed's new #EphyEmbedSecurityLevel
- *
- * The ::ge_security_change signal is emitted when the security level of @embed
- * changes. For example, this will happen when the user browses from an
- * insecure website to an SSL-secured one.
- **/
-		g_signal_new ("ge_security_change",
-			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedIface, security_change),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__ENUM,
-			      G_TYPE_NONE,
-			      1,
-			      EPHY_TYPE_EMBED_SECURITY_LEVEL);
-/**
- * EphyEmbed::ge-zoom-change:
- * @embed:
- * @zoom: @embed's new zoom level
- *
- * The ::ge_zoom_change signal is emitted when @embed's zoom changes. This can
- * be manual (the user modified the zoom level) or automatic (@embed's zoom is
- * automatically changed when browsing to a new site for which the user
- * previously specified a zoom level).
- *
- * A @zoom value of 1.0 indicates 100% (normal zoom).
- **/
-		g_signal_new ("ge_zoom_change",
-			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedIface, zoom_change),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__FLOAT,
-			      G_TYPE_NONE,
-			      1,
-			      G_TYPE_FLOAT);
-/**
- * EphyEmbed::ge-content-change:
- * @embed:
- * @uri: URI of the new content
- *
- * The ::ge_content_change signal is emitted when a new page content
- * is being loadedinto the browser. It's a good place to do view
- * related changes, for example to restore the zoom level of a page
- * or to set an user style sheet.
- **/
-		g_signal_new ("ge_content_change",
-			      EPHY_TYPE_EMBED,
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedIface, content_change),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__STRING,
-			      G_TYPE_NONE,
-			      1,
-			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
-
 /**
  * EphyEmbed::ge-modal-alert:
  * @embed:
@@ -422,9 +323,30 @@ ephy_embed_base_init (gpointer g_class)
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+/**
+ * EphyEmbed::new-document-now:
+ * @embed:
+ * @uri: URI of the new content
+ *
+ * The ::new-document-now signal is emitted when a new page content
+ * is being loaded into the browser. It's a good place to do view
+ * related changes, for example to restore the zoom level of a page
+ * or to set an user style sheet.
+ **/
+	       g_signal_new ("new-document-now",
+			     EPHY_TYPE_EMBED,
+			     G_SIGNAL_RUN_FIRST,
+			     G_STRUCT_OFFSET (EphyEmbedIface, new_document_now),
+			     NULL, NULL,
+			     g_cclosure_marshal_VOID__STRING,
+			     G_TYPE_NONE,
+			     1,
+			     G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+
 
 		initialized = TRUE;
 	}
+
 }
 
 /**
@@ -461,45 +383,6 @@ ephy_embed_load (EphyEmbed *embed,
 	iface->load (embed, url, flags, referring_embed);
 }
 
-/**
- * ephy_embed_stop_load:
- * @embed: an #EphyEmbed
- *
- * If @embed is loading, stops it from continuing.
- **/
-void
-ephy_embed_stop_load (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->stop_load (embed);
-}
-
-/**
- * ephy_embed_can_go_back:
- * @embed: an #EphyEmbed
- *
- * Return value: %TRUE if @embed can return to a previously-visited location
- **/
-gboolean
-ephy_embed_can_go_back (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->can_go_back (embed);
-}
-
-/**
- * ephy_embed_can_go_forward:
- * @embed: an #EphyEmbed
- *
- * Return value: %TRUE if @embed has gone back, and can thus go forward again
- **/
-gboolean
-ephy_embed_can_go_forward (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->can_go_forward (embed);
-}
-
 /**
  * ephy_embed_can_go_up:
  * @embed: an #EphyEmbed
@@ -537,33 +420,6 @@ ephy_embed_get_go_up_list (EphyEmbed *embed)
 	return iface->get_go_up_list (embed);
 }
 
-/**
- * ephy_embed_go_back:
- * @embed: an #EphyEmbed
- *
- * Causes @embed to return to the previously-visited web page.
- **/
-void
-ephy_embed_go_back (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->go_back (embed);
-}
-
-/**
- * ephy_embed_go_forward:
- * @embed: an #EphyEmbed
- *
- * If @embed has returned to a previously-visited web page, proceed forward to
- * the next page.
- **/
-void
-ephy_embed_go_forward (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->go_forward (embed);
-}
-
 /**
  * ephy_embed_go_up:
  * @embed: an #EphyEmbed
@@ -583,7 +439,7 @@ ephy_embed_go_up (EphyEmbed *embed)
  *
  * Return value: the title of the web page displayed in @embed
  **/
-char *
+const char *
 ephy_embed_get_title (EphyEmbed *embed)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
@@ -621,7 +477,7 @@ ephy_embed_get_location (EphyEmbed *embed,
  *
  * Return value: the URL of the link over which the mouse is hovering
  **/
-char *
+const char *
 ephy_embed_get_link_message (EphyEmbed *embed)
 {
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
@@ -637,7 +493,7 @@ ephy_embed_get_link_message (EphyEmbed *embed)
  * Note that Epiphany does not display JavaScript statusbar messages.
  *
  * Return value: a message from JavaScript meant to be displayed in the
- *               statusbar
+ *		 statusbar
  **/
 char *
 ephy_embed_get_js_status (EphyEmbed *embed)
@@ -646,187 +502,6 @@ ephy_embed_get_js_status (EphyEmbed *embed)
 	return iface->get_js_status (embed);
 }
 
-/**
- * ephy_embed_reload:
- * @embed: an #EphyEmbed
- * @force: %TRUE to bypass cache
- *
- * Reloads the web page being displayed in @embed.
- *
- * If @force is %TRUE, cache and proxy will be bypassed when
- * reloading the page.
- **/
-void
-ephy_embed_reload (EphyEmbed *embed,
-		   gboolean force)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->reload (embed, force);
-}
-
-/**
- * ephy_embed_set_zoom:
- * @embed: an #EphyEmbed
- * @zoom: the new zoom level
- *
- * Sets the zoom level for a web page.
- *
- * Zoom is normally controlled by the Epiphany itself and remembered in
- * Epiphany's history data. Be very careful not to break this behavior if using
- * this function; better yet, don't use this function at all.
- **/
-void
-ephy_embed_set_zoom (EphyEmbed *embed,
-		     float zoom)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->set_zoom (embed, zoom);
-}
-
-/**
- * ephy_embed_get_zoom:
- * @embed: an #EphyEmbed
- *
- * Returns the zoom level of @embed. A zoom of 1.0 corresponds to 100% (normal
- * size).
- *
- * Return value: the zoom level of @embed
- **/
-float
-ephy_embed_get_zoom (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->get_zoom (embed);
-}
-
-/**
- * ephy_embed_scroll:
- * @embed: an #EphyEmbed
- * @num_lines: The number of lines to scroll by
- *
- * Scrolls the view by lines. Positive numbers scroll down, negative
- * numbers scroll up
- *
- **/
-void
-ephy_embed_scroll (EphyEmbed *embed,
-		   int num_lines)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->scroll_lines (embed, num_lines);
-}
-
-/**
- * ephy_embed_page_scroll:
- * @embed: an #EphyEmbed
- * @num_lines: The number of pages to scroll by
- *
- * Scrolls the view by pages. Positive numbers scroll down, negative
- * numbers scroll up
- *
- **/
-void
-ephy_embed_page_scroll (EphyEmbed *embed,
-			int num_pages)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->scroll_pages (embed, num_pages);
-}
-
-/**
- * ephy_embed_scroll_pixels:
- * @embed: an #EphyEmbed
- * @dx: the number of pixels to scroll in X direction
- * @dy: the number of pixels to scroll in Y direction
- *
- * Scrolls the view by pixels. Positive numbers scroll down resp. right,
- * negative numbers scroll up resp. left.
- *
- **/
-void
-ephy_embed_scroll_pixels (EphyEmbed *embed,
-			  int dx,
-			  int dy)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->scroll_pixels (embed, dx, dy);
-}
-
-/**
- * ephy_embed_shistory_n_items:
- * @embed: an #EphyEmbed
- *
- * Returns the number of items in @embed's history. In other words, returns the
- * number of pages @embed has visited.
- *
- * The number is upper-bound by Mozilla's browser.sessionhistory.max_entries
- * preference.
- *
- * Return value: the number of items in @embed's history
- **/
-int
-ephy_embed_shistory_n_items  (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->shistory_n_items (embed);
-}
-
-/**
- * ephy_embed_shistory_get_nth:
- * @embed: an #EphyEmbed
- * @nth: index of the desired page in @embed's browser history
- * @is_relative: if %TRUE, add @embed's current history position to @nth
- * @url: returned value of the history entry's URL
- * @title: returned value of the history entry's title
- *
- * Fetches the @url and @title of the @nth item in @embed's session history.
- * If @is_relative is %TRUE, @nth is an offset from the browser's current
- * history position. For example, calling this function with @is_relative %TRUE
- * and @nth %0 will return the URL and title of the current page.
- **/
-void
-ephy_embed_shistory_get_nth (EphyEmbed *embed,
-			     int nth,
-			     gboolean is_relative,
-			     char **url,
-			     char **title)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->shistory_get_nth (embed, nth, is_relative, url, title);
-}
-
-/**
- * ephy_embed_shistory_get_pos:
- * @embed: an #EphyEmbed
- *
- * Returns @embed's current position in its history. If the user never uses the
- * "Back" button, this number will be the same as the return value of
- * ephy_embed_shistory_n_items().
- *
- * Return value: @embed's current position in its history
- **/
-int
-ephy_embed_shistory_get_pos (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->shistory_get_pos (embed);
-}
-
-/**
- * ephy_embed_shistory_go_nth:
- * @embed: an #EphyEmbed
- * @nth: desired history index
- *
- * Opens the webpage at location @nth in @embed's history.
- **/
-void
-ephy_embed_shistory_go_nth (EphyEmbed *embed,
-			    int nth)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->shistory_go_nth (embed, nth);
-}
-
 /**
  * ephy_embed_shistory_copy:
  * @source: the #EphyEmbed to copy the history from
@@ -880,78 +555,6 @@ ephy_embed_show_page_certificate (EphyEmbed *embed)
 	iface->show_page_certificate (embed);
 }
 
-/**
- * ephy_embed_close:
- * @embed: an #EphyEmbed
- *
- * Closes the @embed
- **/
-void
-ephy_embed_close (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->close (embed);
-}
-
-/**
- * ephy_embed_set_encoding:
- * @embed: an #EphyEmbed
- * @encoding: the desired encoding
- *
- * Sets @embed's character encoding to @encoding. These cryptic encoding
- * strings are listed in <filename>embed/ephy-encodings.c</filename>.
- *
- * Pass an empty string (not NULL) in @encoding to reset @embed to use the
- * document-specified encoding.
- **/
-void
-ephy_embed_set_encoding (EphyEmbed *embed,
-			 const char *encoding)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->set_encoding (embed, encoding);
-}
-
-/**
- * ephy_embed_get_encoding:
- * @embed: an #EphyEmbed
- *
- * Returns the @embed's document's encoding
- **/
-char *
-ephy_embed_get_encoding (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->get_encoding (embed);
-}
-
-/**
- * ephy_embed_has_automatic_encoding:
- * @embed: an #EphyEmbed
- *
- * Returns whether the @embed's document's was determined by the document itself
- **/
-gboolean
-ephy_embed_has_automatic_encoding (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	return iface->has_automatic_encoding (embed);
-}
-
-/**
- * ephy_embed_print:
- * @embed: an #EphyEmbed
- *
- * Sends a document to the printer.
- *
- **/
-void
-ephy_embed_print (EphyEmbed *embed)
-{
-	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
-	iface->print (embed);
-}
-
 /**
  * ephy_embed_set_print_preview_mode:
  * @embed: an #EphyEmbed
@@ -1015,3 +618,210 @@ ephy_embed_has_modified_forms (EphyEmbed *embed)
 	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
 	return iface->has_modified_forms (embed);
 }
+
+/**
+ * ephy_embed_get_document_type:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the type of document loaded in the @embed
+ *
+ * Return value: the #EphyEmbedDocumentType
+ **/
+EphyEmbedDocumentType
+ephy_embed_get_document_type (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_document_type (embed);
+}
+
+/**
+ * ephy_embed_get_load_percent:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the page load percentage (displayed in the progressbar).
+ *
+ * Return value: a percentage from 0 to 100.
+ **/
+int
+ephy_embed_get_load_percent (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_load_percent (embed);
+}
+
+/**
+ * ephy_embed_get_load_status:
+ * @embed: an #EphyEmbed
+ *
+ * Returns whether the web page in @embed has finished loading. A web page is
+ * only finished loading after all images, styles, and other dependencies have
+ * been downloaded and rendered.
+ *
+ * Return value: %TRUE if the page is still loading, %FALSE if complete
+ **/
+gboolean
+ephy_embed_get_load_status (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_load_status (embed);
+}
+
+/**
+ * ephy_embed_get_navigation_flags:
+ * @embed: an #EphyEmbed
+ *
+ * Returns @embed's navigation flags.
+ *
+ * Return value: @embed's navigation flags
+ **/
+EphyEmbedNavigationFlags
+ephy_embed_get_navigation_flags (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_navigation_flags (embed);
+}
+
+/**
+ * ephy_embed_get_typed_address:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the text that @embed's #EphyWindow will display in its location toolbar
+ * entry when @embed is selected.
+ *
+ * This is not guaranteed to be the same as @embed's location,
+ * available through ephy_embed_get_location(). As the user types a new address
+ * into the location entry, ephy_embed_get_location()'s returned string will
+ * change.
+ *
+ * Return value: @embed's #EphyWindow's location entry when @embed is selected
+ **/
+const char *
+ephy_embed_get_typed_address (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_typed_address (embed);
+}
+
+/**
+ * ephy_embed_set_typed_address:
+ * @embed: an #EphyEmbed
+ * @address: the new typed address, or %NULL to clear it
+ * @expire: when to expire this address_expire
+ * 
+ * Sets the text that @embed's #EphyWindow will display in its location toolbar
+ * entry when @embed is selected.
+ **/
+void
+ephy_embed_set_typed_address (EphyEmbed *embed,
+			      const char *address,
+			      EphyEmbedAddressExpire expire)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->set_typed_address (embed, address, expire);
+}
+
+/**
+ * ephy_embed_get_address:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the address of the currently loaded page.
+ *
+ * Return value: @embed's address. Will never be %NULL.
+ **/
+const char *
+ephy_embed_get_address (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_address (embed);
+}
+
+/**
+ * ephy_embed_get_status_message:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the message displayed in @embed's #EphyWindow's
+ * #EphyStatusbar. If the user is hovering the mouse over a hyperlink,
+ * this function will return the same value as
+ * ephy_embed_get_link_message(). Otherwise, it will return a network
+ * status message, or NULL.
+ *
+ * The message returned has a limited lifetime, and so should be copied with
+ * g_strdup() if it must be stored.
+ *
+ * Return value: The current statusbar message
+ **/
+const char *
+ephy_embed_get_status_message (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_status_message (embed);
+}
+
+/**
+ * ephy_embed_get_icon:
+ * @embed: an #EphyEmbed
+ *
+ * Returns the embed's site icon as a #GdkPixbuf,
+ * or %NULL if it is not available.
+ *
+ * Return value: a the embed's site icon
+ **/
+GdkPixbuf *
+ephy_embed_get_icon (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_icon (embed);
+}
+
+/**
+ * ephy_embed_get_icon_address:
+ * @embed: an #EphyEmbed
+ *
+ * Returns a URL which points to @embed's site icon.
+ *
+ * Return value: the URL of @embed's site icon
+ **/
+const char *
+ephy_embed_get_icon_address (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_icon_address (embed);
+}
+
+/**
+ * ephy_embed_get_is_blank:
+ * @embed: an #EphyEmbed
+ *
+ * Returns whether the	@embed's address is "blank".
+ *
+ * Return value: %TRUE if the @embed's address is "blank"
+ **/
+gboolean
+ephy_embed_get_is_blank (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_is_blank (embed);
+}
+
+const char *
+ephy_embed_get_loading_title (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_loading_title (embed);
+}
+
+/**
+ * ephy_embed_get_visibility:
+ * @embed: an #EphyEmbed
+ *
+ * Returns whether the @embed's toplevel is visible or not. Used
+ * mostly for popup visibility management.
+ *
+ * Return value: %TRUE if @embed's "visibility" property is set
+ **/
+gboolean
+ephy_embed_get_visibility (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_visibility (embed);
+}
